@@ -2,6 +2,7 @@
 # encoding: utf-8
 
 import Naked.settings
+from Naked.toolshed.system import exit_success
 
 class Usage:
     def __init__(self):
@@ -9,6 +10,7 @@ class Usage:
 
     def print_usage(self):
         print(self.usage)
+        exit_success()
 
 
 if __name__ == '__main__':
